@@ -177,7 +177,7 @@ def _plotonehist2(x,y,parx,pary,smooth=False,colormap=True,ranges={},labels={},b
     P.gca().xaxis.set_major_formatter(fx)
     P.gca().yaxis.set_major_formatter(fy)
 
-def plothist2(data,pars=[],offsets=[],smooth=False,colormap=True,select=[],ranges={},labels={},bins=50,levels=3,weights=None,
+def plothist2(data,pars=[],offsets=[],smooth=False,colormap=True,select=[],ranges={},labels={},bins=50,levels=3,weights=None,cuts=None,
               diagonal=True,title=None,color='k',linewidth=1,append=False):
     if hasattr(data,'data') and not isinstance(data,N.ndarray):
         # parse a multinestdata structure
@@ -195,9 +195,11 @@ def plothist2(data,pars=[],offsets=[],smooth=False,colormap=True,select=[],range
             offsets = offsets + [0.0] * (m - len(offsets))
         data = data - N.array(offsets)
 
-    if select:
-        m, sel = _select(m,pars,select)
-        data, pars = data[:,sel], [pars[s] for s in sel]
+    if cuts:
+        for i,par in enumerate(pars):
+            if par in cuts:
+                data = data[data[:,i] > cuts[par][0],:]
+                data = data[data[:,i] < cuts[par][1],:]
 
     if weights:
         weight = 1
@@ -210,6 +212,10 @@ def plothist2(data,pars=[],offsets=[],smooth=False,colormap=True,select=[],range
     else:
         weight = None
 
+    if select:
+        m, sel = _select(m,pars,select)
+        data, pars = data[:,sel], [pars[s] for s in sel]
+
     if not append:
         fs = min((m if diagonal else m-1)*4,16)
         P.figure(figsize=(fs,fs))
